==> angular__material-5.2.0.jar: META-INF/resources/webjars/angular__material/5.2.0/typings/esm5/public-api.d.ts <==
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */
export * from './version';
export * from '@angular/material/autocomplete';
export * from '@angular/material/button';
export * from '@angular/material/button-toggle';
export * from '@angular/material/card';
export * from '@angular/material/checkbox';
export * from '@angular/material/chips';
export * from '@angular/material/core';
export * from '@angular/material/datepicker';
export * from '@angular/material/dialog';
export * from '@angular/material/divider';
export * from '@angular/material/expansion';
export * from '@angular/material/form-field';
export * from '@angular/material/grid-list';
export * from '@angular/material/icon';
export * from '@angular/material/input';
export * from '@angular/material/list';
export * from '@angular/material/menu';
export * from '@angular/material/paginator';
export * from '@angular/material/progress-bar';
export * from '@angular/material/progress-spinner';
export * from '@angular/material/radio';
export * from '@angular/material/select';
export * from '@angular/material/sidenav';
export * from '@angular/material/slide-toggle';
export * from '@angular/material/slider';
export * from '@angular/material/snack-bar';
export * from '@angular/material/sort';
export * from '@angular/material/stepper';
export * from '@angular/material/table';
export * from '@angular/material/tabs';
export * from '@angular/material/toolbar';
export * from '@angular/material/tooltip';

==> angular__material-6.1.0.jar: META-INF/resources/webjars/angular__material/6.1.0/typings/esm5/public-api.d.ts <==
/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */
export * from './version';
export * from '@angular/material/autocomplete';
export * from '@angular/material/badge';
export * from '@angular/material/bottom-sheet';
export * from '@angular/material/button';
export * from '@angular/material/button-toggle';
export * from '@angular/material/card';
export * from '@angular/material/checkbox';
export * from '@angular/material/chips';
export * from '@angular/material/core';
export * from '@angular/material/datepicker';
export * from '@angular/material/dialog';
export * from '@angular/material/divider';
export * from '@angular/material/expansion';
export * from '@angular/material/form-field';
export * from '@angular/material/grid-list';
export * from '@angular/material/icon';
export * from '@angular/material/input';
export * from '@angular/material/list';
export * from '@angular/material/menu';
export * from '@angular/material/paginator';
export * from '@angular/material/progress-bar';
export * from '@angular/material/progress-spinner';
export * from '@angular/material/radio';
export * from '@angular/material/select';
export * from '@angular/material/sidenav';
export * from '@angular/material/slide-toggle';
export * from '@angular/material/slider';
export * from '@angular/material/snack-bar';
export * from '@angular/material/sort';
export * from '@angular/material/stepper';
export * from '@angular/material/table';
export * from '@angular/material/tabs';
export * from '@angular/material/toolbar';
export * from '@angular/material/tooltip';
export * from '@angular/material/tree';
